@@ -164,7 +164,7 @@ fit_mlpmms = function(y.names, fixefs, ranef.time,
   if (n.boots > 0) {
     max.cores = parallel::detectCores()
     if (!is.na(max.cores)) {
-      .check_ncores(avail = max.cores, requested = n.cores)
+      .check_ncores(avail = max.cores, requested = n.cores, verbose = verbose)
     }
   }
   
